@@ -7,7 +7,18 @@
 Structured Logging for Python
 """
 
-from structlog import dev, processors, stdlib, testing, threadlocal, types
+from __future__ import annotations
+
+from structlog import (
+    contextvars,
+    dev,
+    processors,
+    stdlib,
+    testing,
+    threadlocal,
+    tracebacks,
+    types,
+)
 from structlog._base import BoundLoggerBase, get_context
 from structlog._config import (
     configure,
@@ -26,6 +37,8 @@ from structlog._loggers import (
     BytesLoggerFactory,
     PrintLogger,
     PrintLoggerFactory,
+    WriteLogger,
+    WriteLoggerFactory,
 )
 from structlog.exceptions import DropEvent
 from structlog.testing import ReturnLogger, ReturnLoggerFactory
@@ -36,13 +49,8 @@ try:
 except ImportError:
     twisted = None  # type: ignore
 
-try:
-    from structlog import contextvars
-except ImportError:
-    contextvars = None  # type: ignore
 
-
-__version__ = "21.5.0"
+__version__ = "22.1.0"
 
 __title__ = "structlog"
 # __doc__ is None when running with PYTHONOPTIMIZE=2 / -OO
@@ -62,27 +70,30 @@ __all__ = [
     "BoundLoggerBase",
     "BytesLogger",
     "BytesLoggerFactory",
-    "DropEvent",
-    "PrintLogger",
-    "PrintLoggerFactory",
-    "ReturnLogger",
-    "ReturnLoggerFactory",
-    "configure",
     "configure_once",
+    "configure",
     "contextvars",
     "dev",
-    "getLogger",
+    "DropEvent",
     "get_config",
     "get_context",
     "get_logger",
+    "getLogger",
     "is_configured",
     "make_filtering_bound_logger",
+    "PrintLogger",
+    "PrintLoggerFactory",
     "processors",
     "reset_defaults",
+    "ReturnLogger",
+    "ReturnLoggerFactory",
     "stdlib",
     "testing",
     "threadlocal",
+    "tracebacks",
     "twisted",
     "types",
     "wrap_logger",
+    "WriteLogger",
+    "WriteLoggerFactory",
 ]
