@@ -7,40 +7,38 @@
 Global state department.  Don't reload this module or everything breaks.
 """
 
+from __future__ import annotations
 
 import sys
 import warnings
 
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    Optional,
-    Sequence,
-    Type,
-    cast,
-)
+from typing import Any, Callable, Iterable, Sequence, Type, cast
 
 from ._log_levels import make_filtering_bound_logger
 from ._loggers import PrintLoggerFactory
+from .contextvars import merge_contextvars
 from .dev import ConsoleRenderer, _use_colors, set_exc_info
 from .processors import StackInfoRenderer, TimeStamper, add_log_level
 from .types import BindableLogger, Context, Processor, WrappedLogger
 
 
 """
-.. note::
+   Any changes to these defaults must be reflected in:
 
-   Any changes to these defaults must be reflected in `getting-started`.
+   - `getting-started`.
+   - structlog.stdlib.recreate_defaults()'s docstring.
 """
 _BUILTIN_DEFAULT_PROCESSORS: Sequence[Processor] = [
+    merge_contextvars,
     add_log_level,
     StackInfoRenderer(),
     set_exc_info,
     TimeStamper(fmt="%Y-%m-%d %H:%M.%S", utc=False),
     ConsoleRenderer(
-        colors=_use_colors and sys.stdout is not None and sys.stdout.isatty()
+        colors=_use_colors
+        and sys.stdout is not None
+        and hasattr(sys.stdout, "isatty")
+        and sys.stdout.isatty()
     ),
 ]
 _BUILTIN_DEFAULT_CONTEXT_CLASS = cast(Type[Context], dict)
@@ -56,7 +54,7 @@ class _Configuration:
 
     is_configured: bool = False
     default_processors: Iterable[Processor] = _BUILTIN_DEFAULT_PROCESSORS[:]
-    default_context_class: Type[Context] = _BUILTIN_DEFAULT_CONTEXT_CLASS
+    default_context_class: type[Context] = _BUILTIN_DEFAULT_CONTEXT_CLASS
     default_wrapper_class: Any = _BUILTIN_DEFAULT_WRAPPER_CLASS
     logger_factory: Callable[
         ..., WrappedLogger
@@ -81,7 +79,7 @@ def is_configured() -> bool:
     return _CONFIG.is_configured
 
 
-def get_config() -> Dict[str, Any]:
+def get_config() -> dict[str, Any]:
     """
     Get a dictionary with the current configuration.
 
@@ -140,12 +138,12 @@ stick out like a sore thumb in frameworks like Twisted or Zope.
 
 def wrap_logger(
     logger: WrappedLogger,
-    processors: Optional[Iterable[Processor]] = None,
-    wrapper_class: Optional[Type[BindableLogger]] = None,
-    context_class: Optional[Type[Context]] = None,
-    cache_logger_on_first_use: Optional[bool] = None,
-    logger_factory_args: Optional[Iterable[Any]] = None,
-    **initial_values: Any
+    processors: Iterable[Processor] | None = None,
+    wrapper_class: type[BindableLogger] | None = None,
+    context_class: type[Context] | None = None,
+    cache_logger_on_first_use: bool | None = None,
+    logger_factory_args: Iterable[Any] | None = None,
+    **initial_values: Any,
 ) -> Any:
     """
     Create a new bound logger for an arbitrary *logger*.
@@ -183,11 +181,11 @@ def wrap_logger(
 
 
 def configure(
-    processors: Optional[Iterable[Processor]] = None,
-    wrapper_class: Optional[Type[BindableLogger]] = None,
-    context_class: Optional[Type[Context]] = None,
-    logger_factory: Optional[Callable[..., WrappedLogger]] = None,
-    cache_logger_on_first_use: Optional[bool] = None,
+    processors: Iterable[Processor] | None = None,
+    wrapper_class: type[BindableLogger] | None = None,
+    context_class: type[Context] | None = None,
+    logger_factory: Callable[..., WrappedLogger] | None = None,
+    cache_logger_on_first_use: bool | None = None,
 ) -> None:
     """
     Configures the **global** defaults.
@@ -233,11 +231,11 @@ def configure(
 
 
 def configure_once(
-    processors: Optional[Iterable[Processor]] = None,
-    wrapper_class: Optional[Type[BindableLogger]] = None,
-    context_class: Optional[Type[Context]] = None,
-    logger_factory: Optional[Callable[..., WrappedLogger]] = None,
-    cache_logger_on_first_use: Optional[bool] = None,
+    processors: Iterable[Processor] | None = None,
+    wrapper_class: type[BindableLogger] | None = None,
+    context_class: type[Context] | None = None,
+    logger_factory: Callable[..., WrappedLogger] | None = None,
+    cache_logger_on_first_use: bool | None = None,
 ) -> None:
     """
     Configures if structlog isn't configured yet.
@@ -292,11 +290,11 @@ class BoundLoggerLazyProxy:
     def __init__(
         self,
         logger: WrappedLogger,
-        wrapper_class: Optional[Type[BindableLogger]] = None,
-        processors: Optional[Iterable[Processor]] = None,
-        context_class: Optional[Type[Context]] = None,
-        cache_logger_on_first_use: Optional[bool] = None,
-        initial_values: Optional[Dict[str, Any]] = None,
+        wrapper_class: type[BindableLogger] | None = None,
+        processors: Iterable[Processor] | None = None,
+        context_class: type[Context] | None = None,
+        cache_logger_on_first_use: bool | None = None,
+        initial_values: dict[str, Any] | None = None,
         logger_factory_args: Any = None,
     ) -> None:
         self._logger = logger
@@ -392,13 +390,13 @@ class BoundLoggerLazyProxy:
 
         return getattr(bl, name)
 
-    def __getstate__(self) -> Dict[str, Any]:
+    def __getstate__(self) -> dict[str, Any]:
         """
         Our __getattr__ magic makes this necessary.
         """
         return self.__dict__
 
-    def __setstate__(self, state: Dict[str, Any]) -> None:
+    def __setstate__(self, state: dict[str, Any]) -> None:
         """
         Our __getattr__ magic makes this necessary.
         """
