@@ -3,12 +3,13 @@
 # 2.0, and the MIT License.  See the LICENSE file in the root of this
 # repository for complete details.
 
+from __future__ import annotations
+
 import sys
 import traceback
 
 from io import StringIO
 from types import FrameType
-from typing import List, Optional, Tuple
 
 from .types import ExcInfo
 
@@ -31,8 +32,8 @@ def _format_exception(exc_info: ExcInfo) -> str:
 
 
 def _find_first_app_frame_and_name(
-    additional_ignores: Optional[List[str]] = None,
-) -> Tuple[FrameType, str]:
+    additional_ignores: list[str] | None = None,
+) -> tuple[FrameType, str]:
     """
     Remove all intra-structlog calls and return the relevant app frame.
 
