@@ -9,16 +9,18 @@ Helpers that make development with ``structlog`` more pleasant.
 See also the narrative documentation in `development`.
 """
 
+from __future__ import annotations
+
 import sys
 import warnings
 
 from io import StringIO
-from typing import Any, Iterable, Optional, TextIO, Type, Union
+from typing import Any, Iterable, TextIO, Type, Union
 
 from ._frames import _format_exception
 from .types import (
     EventDict,
-    ExceptionFormatter,
+    ExceptionRenderer,
     ExcInfo,
     Protocol,
     WrappedLogger,
@@ -202,7 +204,7 @@ def better_traceback(sio: TextIO, exc_info: ExcInfo) -> None:
 
 if rich is not None:
     default_exception_formatter = rich_traceback
-elif better_exceptions is not None:  # type: ignore
+elif better_exceptions is not None:
     default_exception_formatter = better_traceback
 else:
     default_exception_formatter = plain_traceback
@@ -237,6 +239,8 @@ class ConsoleRenderer:
         `plain_traceback`, `better_traceback`, `rich_traceback`, or implement
         your own.
     :param sort_keys: Whether to sort keys when formatting. `True` by default.
+    :param event_key: The key to look for the main log message. Needed when
+        you rename it e.g. using `structlog.processors.EventRenamer`.
 
     Requires the colorama_ package if *colors* is `True` **on Windows**.
 
@@ -268,6 +272,7 @@ class ConsoleRenderer:
        non-Windows systems, and either True or False in Windows depending on
        whether colorama is installed.
     .. versionadded:: 21.3.0 *sort_keys*
+    .. versionadded:: 22.1 *event_key*
     """
 
     def __init__(
@@ -276,9 +281,10 @@ class ConsoleRenderer:
         colors: bool = _use_colors,
         force_colors: bool = False,
         repr_native_str: bool = False,
-        level_styles: Optional[Styles] = None,
-        exception_formatter: ExceptionFormatter = default_exception_formatter,
+        level_styles: Styles | None = None,
+        exception_formatter: ExceptionRenderer = default_exception_formatter,
         sort_keys: bool = True,
+        event_key: str = "event",
     ):
         styles: Styles
         if colors:
@@ -321,6 +327,7 @@ class ConsoleRenderer:
         self._repr_native_str = repr_native_str
         self._exception_formatter = exception_formatter
         self._sort_keys = sort_keys
+        self._event_key = event_key
 
     def _repr(self, val: Any) -> str:
         """
@@ -361,7 +368,7 @@ class ConsoleRenderer:
             )
 
         # force event to str for compatibility with standard library
-        event = event_dict.pop("event", None)
+        event = event_dict.pop(self._event_key, None)
         if not isinstance(event, str):
             event = str(event)
 
