@@ -7,6 +7,8 @@
 Processors useful regardless of the logging framework.
 """
 
+from __future__ import annotations
+
 import datetime
 import enum
 import inspect
@@ -23,15 +25,9 @@ from typing import (
     Callable,
     ClassVar,
     Collection,
-    Dict,
-    List,
     NamedTuple,
-    Optional,
     Sequence,
-    Set,
     TextIO,
-    Tuple,
-    Union,
 )
 
 from ._frames import (
@@ -41,22 +37,25 @@ from ._frames import (
 )
 from ._log_levels import _NAME_TO_LEVEL, add_log_level
 from ._utils import get_processname
-from .types import EventDict, ExcInfo, WrappedLogger
+from .tracebacks import ExceptionDictTransformer
+from .types import EventDict, ExceptionTransformer, ExcInfo, WrappedLogger
 
 
 __all__ = [
     "_NAME_TO_LEVEL",  # some people rely on it being here
-    "KeyValueRenderer",
-    "TimeStamper",
     "add_log_level",
-    "UnicodeEncoder",
-    "UnicodeDecoder",
-    "JSONRenderer",
-    "format_exc_info",
-    "ExceptionPrettyPrinter",
-    "StackInfoRenderer",
     "CallsiteParameter",
     "CallsiteParameterAdder",
+    "dict_tracebacks",
+    "EventRenamer",
+    "ExceptionPrettyPrinter",
+    "format_exc_info",
+    "JSONRenderer",
+    "KeyValueRenderer",
+    "StackInfoRenderer",
+    "TimeStamper",
+    "UnicodeDecoder",
+    "UnicodeEncoder",
 ]
 
 
@@ -83,7 +82,7 @@ class KeyValueRenderer:
     def __init__(
         self,
         sort_keys: bool = False,
-        key_order: Optional[Sequence[str]] = None,
+        key_order: Sequence[str] | None = None,
         drop_missing: bool = False,
         repr_native_str: bool = True,
     ):
@@ -133,7 +132,7 @@ class LogfmtRenderer:
     def __init__(
         self,
         sort_keys: bool = False,
-        key_order: Optional[Sequence[str]] = None,
+        key_order: Sequence[str] | None = None,
         drop_missing: bool = False,
         bool_as_flag: bool = True,
     ):
@@ -144,7 +143,7 @@ class LogfmtRenderer:
         self, _: WrappedLogger, __: str, event_dict: EventDict
     ) -> str:
 
-        elements: List[str] = []
+        elements: list[str] = []
         for key, value in self._ordered_items(event_dict):
             if any(c <= " " for c in key):
                 raise ValueError(f'Invalid key: "{key}"')
@@ -171,9 +170,9 @@ class LogfmtRenderer:
 
 def _items_sorter(
     sort_keys: bool,
-    key_order: Optional[Sequence[str]],
+    key_order: Sequence[str] | None,
     drop_missing: bool,
-) -> Callable[[EventDict], List[Tuple[str, Any]]]:
+) -> Callable[[EventDict], list[tuple[str, Any]]]:
     """
     Return a function to sort items from an ``event_dict``.
 
@@ -182,7 +181,7 @@ def _items_sorter(
     # Use an optimized version for each case.
     if key_order and sort_keys:
 
-        def ordered_items(event_dict: EventDict) -> List[Tuple[str, Any]]:
+        def ordered_items(event_dict: EventDict) -> list[tuple[str, Any]]:
             items = []
             for key in key_order:  # type: ignore
                 value = event_dict.pop(key, None)
@@ -195,7 +194,7 @@ def _items_sorter(
 
     elif key_order:
 
-        def ordered_items(event_dict: EventDict) -> List[Tuple[str, Any]]:
+        def ordered_items(event_dict: EventDict) -> list[tuple[str, Any]]:
             items = []
             for key in key_order:  # type: ignore
                 value = event_dict.pop(key, None)
@@ -208,7 +207,7 @@ def _items_sorter(
 
     elif sort_keys:
 
-        def ordered_items(event_dict: EventDict) -> List[Tuple[str, Any]]:
+        def ordered_items(event_dict: EventDict) -> list[tuple[str, Any]]:
             return sorted(event_dict.items())
 
     else:
@@ -287,17 +286,16 @@ class UnicodeDecoder:
 
 class JSONRenderer:
     """
-    Render the ``event_dict`` using ``serializer(event_dict, **json_kw)``.
+    Render the ``event_dict`` using ``serializer(event_dict, **dumps_kw)``.
 
-    :param json_kw: Are passed unmodified to *serializer*.  If *default*
+    :param dumps_kw: Are passed unmodified to *serializer*.  If *default*
         is passed, it will disable support for ``__structlog__``-based
         serialization.
     :param serializer: A :func:`json.dumps`-compatible callable that
         will be used to format the string.  This can be used to use alternative
-        JSON encoders like `simplejson
-        <https://pypi.org/project/simplejson/>`_ or `RapidJSON
-        <https://pypi.org/project/python-rapidjson/>`_ (faster but Python
-        3-only) (default: :func:`json.dumps`).
+        JSON encoders like `orjson <https://pypi.org/project/orjson/>`__ or
+        `RapidJSON <https://pypi.org/project/python-rapidjson/>`_  (default:
+        :func:`json.dumps`).
 
     .. versionadded:: 0.2.0
         Support for ``__structlog__`` serialization method.
@@ -312,7 +310,7 @@ class JSONRenderer:
 
     def __init__(
         self,
-        serializer: Callable[..., Union[str, bytes]] = json.dumps,
+        serializer: Callable[..., str | bytes] = json.dumps,
         **dumps_kw: Any,
     ) -> None:
         dumps_kw.setdefault("default", _json_fallback_handler)
@@ -321,7 +319,7 @@ class JSONRenderer:
 
     def __call__(
         self, logger: WrappedLogger, name: str, event_dict: EventDict
-    ) -> Union[str, bytes]:
+    ) -> str | bytes:
         """
         The return type of this depends on the return type of self._dumps.
         """
@@ -344,30 +342,83 @@ def _json_fallback_handler(obj: Any) -> Any:
             return repr(obj)
 
 
-def format_exc_info(
-    logger: WrappedLogger, name: str, event_dict: EventDict
-) -> EventDict:
+class ExceptionRenderer:
     """
-    Replace an ``exc_info`` field by an ``exception`` string field:
+    Replace an ``exc_info`` field with an ``exception`` field which is rendered
+    by *exception_formatter*.
 
-    If *event_dict* contains the key ``exc_info``, there are two possible
+    The contents of the ``exception`` field depends on the return value of the
+    :class:`.ExceptionTransformer` that is used:
+
+    - The default produces a formatted string via Python's built-in traceback
+      formatting.
+    - The :class:`~structlog.tracebacks.ExceptionDictTransformer` a list of
+      stack dicts that can be serialized to JSON.
+
+    If *event_dict* contains the key ``exc_info``, there are three possible
     behaviors:
 
-    - If the value is a tuple, render it into the key ``exception``.
-    - If the value is an Exception render it into the key ``exception``.
-    - If the value true but no tuple, obtain exc_info ourselves and render
-      that.
+    1. If the value is a tuple, render it into the key ``exception``.
+    2. If the value is an Exception render it into the key ``exception``.
+    3. If the value true but no tuple, obtain exc_info ourselves and render
+       that.
 
     If there is no ``exc_info`` key, the *event_dict* is not touched.
     This behavior is analogue to the one of the stdlib's logging.
-    """
-    exc_info = event_dict.pop("exc_info", None)
-    if exc_info:
-        event_dict["exception"] = _format_exception(
-            _figure_out_exc_info(exc_info)
-        )
 
-    return event_dict
+    :param exception_formatter: A callable that is used to format the exception
+        from the ``exc_info`` field.
+
+    .. versionadded:: 22.1
+    """
+
+    def __init__(
+        self,
+        exception_formatter: ExceptionTransformer = _format_exception,
+    ) -> None:
+        self.format_exception = exception_formatter
+
+    def __call__(
+        self, logger: WrappedLogger, name: str, event_dict: EventDict
+    ) -> EventDict:
+        exc_info = event_dict.pop("exc_info", None)
+        if exc_info:
+            event_dict["exception"] = self.format_exception(
+                _figure_out_exc_info(exc_info)
+            )
+
+        return event_dict
+
+
+format_exc_info = ExceptionRenderer()
+"""
+Replace an ``exc_info`` field with an ``exception`` string field using
+Python's built-in traceback formatting.
+
+If *event_dict* contains the key ``exc_info``, there are three possible
+behaviors:
+
+1. If the value is a tuple, render it into the key ``exception``.
+2. If the value is an Exception render it into the key ``exception``.
+3. If the value is true but no tuple, obtain exc_info ourselves and render
+   that.
+
+If there is no ``exc_info`` key, the *event_dict* is not touched.
+This behavior is analogue to the one of the stdlib's logging.
+"""
+
+dict_tracebacks = ExceptionRenderer(ExceptionDictTransformer())
+"""
+Replace an ``exc_info`` field with an ``exception`` field containing structured
+tracebacks suiteable for, e.g., JSON output.
+
+It is a shortcut for :class:`ExceptionRenderer` with a
+:class:`~structlog.tracebacks.ExceptionDictTransformer`.
+
+The treatment of the ``exc_info`` key is identical to `format_exc_info`.
+
+.. versionadded:: 22.1
+"""
 
 
 class TimeStamper:
@@ -387,7 +438,7 @@ class TimeStamper:
 
     def __init__(
         self,
-        fmt: Optional[str] = None,
+        fmt: str | None = None,
         utc: bool = True,
         key: str = "timestamp",
     ) -> None:
@@ -400,10 +451,10 @@ class TimeStamper:
     ) -> EventDict:
         return self._stamper(event_dict)
 
-    def __getstate__(self) -> Dict[str, Any]:
+    def __getstate__(self) -> dict[str, Any]:
         return {"fmt": self.fmt, "utc": self.utc, "key": self.key}
 
-    def __setstate__(self, state: Dict[str, Any]) -> None:
+    def __setstate__(self, state: dict[str, Any]) -> None:
         self.fmt = state["fmt"]
         self.utc = state["utc"]
         self.key = state["key"]
@@ -412,7 +463,7 @@ class TimeStamper:
 
 
 def _make_stamper(
-    fmt: Optional[str], utc: bool, key: str
+    fmt: str | None, utc: bool, key: str
 ) -> Callable[[EventDict], EventDict]:
     """
     Create a stamper function.
@@ -500,7 +551,11 @@ class ExceptionPrettyPrinter:
        Added support for passing exceptions as ``exc_info`` on Python 3.
     """
 
-    def __init__(self, file: Optional[TextIO] = None) -> None:
+    def __init__(
+        self,
+        file: TextIO | None = None,
+        exception_formatter: ExceptionTransformer = _format_exception,
+    ) -> None:
         if file is not None:
             self._file = file
         else:
@@ -526,20 +581,32 @@ class StackInfoRenderer:
     Add stack information with key ``stack`` if ``stack_info`` is `True`.
 
     Useful when you want to attach a stack dump to a log entry without
-    involving an exception.
+    involving an exception and works analogously to the *stack_info* argument
+    of the Python standard library logging.
 
-    It works analogously to the *stack_info* argument of the Python 3 standard
-    library logging.
+    :param additional_ignores: By default, stack frames coming from
+        ``structlog`` are ignored. With this argument you can add additional
+        names that are ignored, before the stack starts being rendered. They
+        are matched using ``startswith()``, so they don't have to match
+        exactly. The names are used to find the first relevant name, therefore
+        once a frame is found that doesn't start with ``structlog`` or one of
+        *additional_ignores*, **no filtering** is applied to subsequent frames.
 
     .. versionadded:: 0.4.0
+    .. versionadded:: 22.1.0  *additional_ignores*
     """
 
+    __slots__ = ["_additional_ignores"]
+
+    def __init__(self, additional_ignores: list[str] | None = None) -> None:
+        self._additional_ignores = additional_ignores
+
     def __call__(
         self, logger: WrappedLogger, name: str, event_dict: EventDict
     ) -> EventDict:
         if event_dict.pop("stack_info", None):
             event_dict["stack"] = _format_stack(
-                _find_first_app_frame_and_name()[0]
+                _find_first_app_frame_and_name(self._additional_ignores)[0]
             )
 
         return event_dict
@@ -622,7 +689,7 @@ class CallsiteParameterAdder:
     """
 
     _handlers: ClassVar[
-        Dict[CallsiteParameter, Callable[[str, inspect.Traceback], Any]]
+        dict[CallsiteParameter, Callable[[str, inspect.Traceback], Any]]
     ] = {
         CallsiteParameter.PATHNAME: (
             lambda module, frame_info: frame_info.filename
@@ -652,7 +719,7 @@ class CallsiteParameterAdder:
             lambda module, frame_info: get_processname()
         ),
     }
-    _record_attribute_map: ClassVar[Dict[CallsiteParameter, str]] = {
+    _record_attribute_map: ClassVar[dict[CallsiteParameter, str]] = {
         CallsiteParameter.PATHNAME: "pathname",
         CallsiteParameter.FILENAME: "filename",
         CallsiteParameter.MODULE: "module",
@@ -664,7 +731,7 @@ class CallsiteParameterAdder:
         CallsiteParameter.PROCESS_NAME: "processName",
     }
 
-    _all_parameters: ClassVar[Set[CallsiteParameter]] = set(CallsiteParameter)
+    _all_parameters: ClassVar[set[CallsiteParameter]] = set(CallsiteParameter)
 
     class _RecordMapping(NamedTuple):
         event_dict_key: str
@@ -679,7 +746,7 @@ class CallsiteParameterAdder:
     def __init__(
         self,
         parameters: Collection[CallsiteParameter] = _all_parameters,
-        additional_ignores: Optional[List[str]] = None,
+        additional_ignores: list[str] | None = None,
     ) -> None:
         if additional_ignores is None:
             additional_ignores = []
@@ -687,12 +754,10 @@ class CallsiteParameterAdder:
         # processor is used in ProcessorFormatter, and additionally the logging
         # module should not be logging using structlog.
         self._additional_ignores = ["logging", *additional_ignores]
-        self._active_handlers: List[
-            Tuple[CallsiteParameter, Callable[[str, inspect.Traceback], Any]]
-        ] = []
-        self._record_mappings: List[
-            "CallsiteParameterAdder._RecordMapping"
+        self._active_handlers: list[
+            tuple[CallsiteParameter, Callable[[str, inspect.Traceback], Any]]
         ] = []
+        self._record_mappings: list[CallsiteParameterAdder._RecordMapping] = []
         for parameter in parameters:
             self._active_handlers.append(
                 (parameter, self._handlers[parameter])
@@ -707,8 +772,8 @@ class CallsiteParameterAdder:
     def __call__(
         self, logger: logging.Logger, name: str, event_dict: EventDict
     ) -> EventDict:
-        record: Optional[logging.LogRecord] = event_dict.get("_record")
-        from_structlog: Optional[bool] = event_dict.get("_from_structlog")
+        record: logging.LogRecord | None = event_dict.get("_record")
+        from_structlog: bool | None = event_dict.get("_from_structlog")
         # If the event dictionary has a record, but it comes from structlog,
         # then the callsite parameters of the record will not be correct.
         if record is not None and not from_structlog:
@@ -724,3 +789,42 @@ class CallsiteParameterAdder:
             for parameter, handler in self._active_handlers:
                 event_dict[parameter.value] = handler(module, frame_info)
         return event_dict
+
+
+class EventRenamer:
+    r"""
+    Rename the ``event`` key in event dicts.
+
+    This is useful if you want to use consistent log message keys across
+    platforms and/or use the ``event`` key for something custom.
+
+    .. warning::
+
+       It's recommended to put this processor right before the renderer, since
+       some processors may rely on the presence and meaning of the ``event``
+       key.
+
+    :param to: Rename ``event_dict["event"]`` to ``event_dict[to]``
+    :param replace_by: Rename ``event_dict[replace_by]`` to
+        ``event_dict["event"]``. *replace_by* missing from ``event_dict`` is
+        handled gracefully.
+
+    .. versionadded:: 22.1
+    """
+
+    def __init__(self, to: str, replace_by: str | None = None):
+        self.to = to
+        self.replace_by = replace_by
+
+    def __call__(
+        self, logger: logging.Logger, name: str, event_dict: EventDict
+    ) -> EventDict:
+        event = event_dict.pop("event")
+        event_dict[self.to] = event
+
+        if self.replace_by is not None:
+            replace_by = event_dict.pop(self.replace_by, None)
+            if replace_by is not None:
+                event_dict["event"] = replace_by
+
+        return event_dict
