@@ -4,16 +4,23 @@
 # repository for complete details.
 
 """
-Primitives to keep context global but thread (and greenlet) local.
+**Deprecated** primitives to keep context global but thread (and greenlet)
+local.
 
-See `thread-local`.
+See `thread-local`, but please use :doc:`contextvars` instead.
+
+.. deprecated:: 22.1.0
 """
 
+from __future__ import annotations
+
 import contextlib
+import sys
 import threading
 import uuid
+import warnings
 
-from typing import Any, Dict, Generator, Iterator, Type, TypeVar
+from typing import Any, Generator, Iterator, TypeVar
 
 import structlog
 
@@ -21,7 +28,7 @@ from ._config import BoundLoggerLazyProxy
 from .types import BindableLogger, Context, EventDict, WrappedLogger
 
 
-def _determine_threadlocal() -> Type[Any]:
+def _determine_threadlocal() -> type[Any]:
     """
     Return a dict-like threadlocal storage depending on whether we run with
     greenlets or not.
@@ -33,20 +40,53 @@ def _determine_threadlocal() -> Type[Any]:
 
         return local
 
-    return GreenThreadLocal
+    return GreenThreadLocal  # pragma: no cover
 
 
 ThreadLocal = _determine_threadlocal()
 
 
-def wrap_dict(dict_class: Type[Context]) -> Type[Context]:
+def _deprecated() -> None:
+    """
+    Raise a warning with best-effort stacklevel adjustment.
+    """
+    callsite = ""
+    try:
+        f = sys._getframe()
+        callsite = f.f_back.f_back.f_globals["__name__"]  # type: ignore
+    except Exception:  # pragma: no cover
+        pass
+
+    # Avoid double warnings if TL functions call themselves.
+    if callsite == "structlog.threadlocal":
+        return
+
+    stacklevel = 3
+    # If a function is used as a decorator, we need to add two stack levels.
+    # This logic will probably break eventually, but it's not worth any more
+    # complexity.
+    if callsite == "contextlib":
+        stacklevel += 2
+
+    warnings.warn(
+        "`structlog.threadlocal` is deprecated, please use "
+        "`structlog.contextvars` instead.",
+        DeprecationWarning,
+        stacklevel=stacklevel,
+    )
+
+
+def wrap_dict(dict_class: type[Context]) -> type[Context]:
     """
     Wrap a dict-like class and return the resulting class.
 
     The wrapped class and used to keep global in the current thread.
 
     :param dict_class: Class used for keeping context.
+
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     Wrapped = type(
         "WrappedDict-" + str(uuid.uuid4()), (_ThreadLocalDictWrapper,), {}
     )
@@ -67,7 +107,10 @@ def as_immutable(logger: TLLogger) -> TLLogger:
       thread local state.
 
     :returns: :class:`~structlog.BoundLogger` with an immutable context.
+
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     if isinstance(logger, BoundLoggerLazyProxy):
         logger = logger.bind()  # type: ignore
 
@@ -96,7 +139,10 @@ def tmp_bind(
 
     Only works with `structlog.threadlocal.wrap_dict`-based contexts.
     Use :func:`~structlog.threadlocal.bound_threadlocal` for new code.
+
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     saved = as_immutable(logger)._context
     try:
         yield logger.bind(**tmp_values)  # type: ignore
@@ -118,7 +164,7 @@ class _ThreadLocalDictWrapper:
     """
 
     _tl: Any
-    _dict_class: Type[Dict[str, Any]]
+    _dict_class: type[dict[str, Any]]
 
     def __init__(self, *args: Any, **kw: Any) -> None:
         """
@@ -181,7 +227,9 @@ def get_threadlocal() -> Context:
     Return a copy of the current thread-local context.
 
     .. versionadded:: 21.2.0
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     return _get_context().copy()
 
 
@@ -191,7 +239,9 @@ def get_merged_threadlocal(bound_logger: BindableLogger) -> Context:
     from *bound_logger*.
 
     .. versionadded:: 21.2.0
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     ctx = _get_context().copy()
     ctx.update(structlog.get_context(bound_logger))
 
@@ -212,7 +262,10 @@ def merge_threadlocal(
     .. versionchanged:: 20.1.0
        This function used to be called ``merge_threadlocal_context`` and that
        name is still kept around for backward compatibility.
+
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     context = _get_context().copy()
     context.update(event_dict)
 
@@ -231,7 +284,9 @@ def clear_threadlocal() -> None:
     request-handling code.
 
     .. versionadded:: 19.2.0
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     _CONTEXT.context = {}
 
 
@@ -243,7 +298,9 @@ def bind_threadlocal(**kw: Any) -> None:
     context to be global (thread-local).
 
     .. versionadded:: 19.2.0
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     _get_context().update(kw)
 
 
@@ -252,7 +309,9 @@ def unbind_threadlocal(*keys: str) -> None:
     Tries to remove bound *keys* from threadlocal logging context if present.
 
     .. versionadded:: 20.1.0
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     context = _get_context()
     for key in keys:
         context.pop(key, None)
@@ -267,7 +326,9 @@ def bound_threadlocal(**kw: Any) -> Generator[None, None, None]:
     Can be used as a context manager or decorator.
 
     .. versionadded:: 21.4.0
+    .. deprecated:: 22.1.0
     """
+    _deprecated()
     context = get_threadlocal()
     saved = {k: context[k] for k in context.keys() & kw.keys()}
 
